@@ -1,3 +1,24 @@
+/* 
+
+ Copyright (c) 2013-2015, Tomas Podermanski
+    
+ This file is part of libnf.net project.
+
+ Libnf is free software: you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation, either version 3 of the License, or
+ (at your option) any later version.
+
+ Libnf is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public License
+ along with libnf.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
+
 /*! \file libnf.h
 	\brief libnf C interface
     The libnf.h is complete public application interface for accessing all 
@@ -130,6 +151,7 @@ typedef struct lnf_brec1_s {
 #define LNF_FLD_CLIENT_NW_DELAY_USEC	0x3e 
 #define LNF_FLD_SERVER_NW_DELAY_USEC	0x3f 
 #define LNF_FLD_APPL_LATENCY_USEC		0x40 
+#define LNF_FLD_FW_EVENT		0x41
 
 /* computed and extra fields */
 #define LNF_FLD_CALC_DURATION	 0xA0 			/* computed : duration in msec  */
