@@ -64,13 +64,6 @@
 
 /* global vars */
 
-#ifdef LNF_THREADS
-static __thread int open_files = 0;
-#else
-static int open_files = 0;
-#endif
-
-
 // required for idet filter in nftree.c
 char 	*CurrentIdent;
 
@@ -84,13 +77,16 @@ char 	*CurrentIdent;
     lzo_align_t __LZO_MMODEL var [ ((size) + (sizeof(lzo_align_t) - 1)) / sizeof(lzo_align_t) ]
 
 static HEAP_ALLOC(wrkmem,LZO1X_1_MEM_COMPRESS);
-static __thread void *lzo_buff;
-static __thread int lzo_initialized = 0;
+
+/* commented by libnf patch */
+//static void *lzo_buff;
+//static int lzo_initialized = 0;
 
 #define ERR_SIZE 256
-static __thread char	error_string[ERR_SIZE];
+static char	error_string[ERR_SIZE];
 
-static int LZO_initialize(void);
+/* modified by libnf patch */
+static int LZO_initialize(nffile_t *nffile);
 
 static int OpenRaw(char *filename, stat_record_t *stat_record, int *compressed);
 
@@ -139,7 +135,8 @@ void SumStatRecords(stat_record_t *s1, stat_record_t *s2) {
 } // End of SumStatRecords
 
 
-static int LZO_initialize(void) {
+/* modified by libnf patch */
+static int LZO_initialize(nffile_t *nffile) {
 
 	if (lzo_init() != LZO_E_OK) {
 			// this usually indicates a compiler bug - try recompiling 
@@ -147,12 +144,13 @@ static int LZO_initialize(void) {
 			LogError("Compression lzo_init() failed.\n");
 			return 0;
 	} 
-	lzo_buff = malloc(BUFFSIZE+ sizeof(data_block_header_t));
-	if ( !lzo_buff ) {
+	/* modified by libnf patch */
+	nffile->lzo_buff = malloc(BUFFSIZE+ sizeof(data_block_header_t));
+	if ( !nffile->lzo_buff ) {
 		LogError("malloc() error in %s line %d: %s\n", __FILE__, __LINE__, strerror(errno) );
 		return 0;
 	}
-	lzo_initialized = 1;
+	nffile->lzo_initialized = 1;
 
 	return 1;
 
@@ -238,15 +236,13 @@ int ret, allocated;
 
 	CurrentIdent		= nffile->file_header->ident;
 
-	if ( FILE_IS_COMPRESSED(nffile) && !lzo_initialized && !LZO_initialize() ) {
+	if ( FILE_IS_COMPRESSED(nffile) && !nffile->lzo_initialized && !LZO_initialize(nffile) ) {
 		if ( allocated ) {
 			DisposeFile(nffile);
 			return NULL;
 		}
     }
 
-	open_files++;
-
 	return nffile;
 
 } // End of OpenFile
@@ -260,15 +256,6 @@ void CloseFile(nffile_t *nffile){
 	if ( nffile->fd )
 		close(nffile->fd);
 
-	open_files--;
-
-	if (open_files == 0 && lzo_initialized && lzo_buff) {
-		free(lzo_buff);
-		lzo_buff = NULL;
-		lzo_initialized = 0;
-	}
-
-
 } // End of CloseFile
 
 int ChangeIdent(char *filename, char *Ident) {
@@ -377,6 +364,10 @@ nffile_t *nffile;
 	nffile->fd	 	= 0;
 	nffile->catalog = NULL;
 
+	/* added by libnf patch */
+	nffile->lzo_buff = NULL;
+	nffile->lzo_initialized = 0;
+
 	// Init file header
 	nffile->file_header = calloc(1, sizeof(file_header_t));
 	if ( !nffile->file_header ) {
@@ -419,8 +410,6 @@ nffile_t *nffile;
 	nffile->block_header->flags		 = 0;
 
 	nffile->buff_ptr = (void *)((pointer_addr_t)nffile->block_header + sizeof(data_block_header_t));
-
-	open_files++;
 	
 	return nffile;
 
@@ -431,6 +420,11 @@ nffile_t *DisposeFile(nffile_t *nffile) {
 	free(nffile->stat_record);
 	if (nffile->block_header) 
 		free(nffile->block_header);
+	/* added by libnf patch */
+	if (nffile->lzo_buff) {
+		free(nffile->lzo_buff);
+		nffile->lzo_initialized = 0;
+	}
 	free(nffile);
 	return NULL;
 } // End of DisposeFile
@@ -484,7 +478,7 @@ int 			flags;
 
 
 	if ( TestFlag(flags, FLAG_COMPRESSED) ) {
-		if ( !lzo_initialized && !LZO_initialize() ) {
+		if ( !nffile->lzo_initialized && !LZO_initialize(nffile) ) {
 			LogError("Failed to initialize compression");
 			close(nffile->fd);
 			return NULL;
@@ -553,7 +547,7 @@ nffile_t		*nffile;
 
 	// initialize output  lzo buffer
 	if ( FILE_IS_COMPRESSED(nffile) ) {
-		if ( !lzo_initialized && !LZO_initialize() ) {
+		if ( !nffile->lzo_initialized && !LZO_initialize(nffile) ) {
 			LogError("Failed to initialize compression");
 			close(nffile->fd);
 			DisposeFile(nffile);
@@ -785,7 +779,8 @@ void 	*read_ptr, *buff;
 		return NF_CORRUPT;
 	}
 
-	buff = FILE_IS_COMPRESSED(nffile) ? lzo_buff : nffile->buff_ptr;
+	/* modified by libnf patch */
+	buff = FILE_IS_COMPRESSED(nffile) ? nffile->lzo_buff : nffile->buff_ptr;
 
 	ret = read(nffile->fd, buff, nffile->block_header->size);
 	if ( ret == nffile->block_header->size ) {
@@ -793,7 +788,8 @@ void 	*read_ptr, *buff;
 		// we have the whole record and are done for now
 		if ( FILE_IS_COMPRESSED(nffile) ) {
 			int r;
-   			r = lzo1x_decompress(lzo_buff,nffile->block_header->size,nffile->buff_ptr,&new_len,NULL);
+			/* modified by libnf patch */
+   			r = lzo1x_decompress(nffile->lzo_buff,nffile->block_header->size,nffile->buff_ptr,&new_len,NULL);
    			if (r != LZO_E_OK ) {
        			/* this should NEVER happen */
 				LogError("ReadBlock() error decompression failed in %s line %d: LZO error: %d\n", __FILE__, __LINE__, r);
@@ -850,7 +846,8 @@ void 	*read_ptr, *buff;
 	if ( FILE_IS_COMPRESSED(nffile) ) {
 		int r;
 		lzo_uint new_len;
-   		r = lzo1x_decompress(lzo_buff, nffile->block_header->size, nffile->buff_ptr, &new_len, NULL);
+		/* modified by libnf patch */
+   		r = lzo1x_decompress(nffile->lzo_buff, nffile->block_header->size, nffile->buff_ptr, &new_len, NULL);
    		if (r != LZO_E_OK ) {
        		/* this should NEVER happen */
 			LogError("ReadBlock() error decompression failed in %s line %d: LZO error: %d\n", __FILE__, __LINE__, r);
@@ -891,7 +888,8 @@ lzo_uint out_len;
 		return ret;
 	} 
 
-	out_block_header = (data_block_header_t *)lzo_buff;
+	/* modified by libnf patch */
+	out_block_header = (data_block_header_t *)nffile->lzo_buff;
 	*out_block_header = *(nffile->block_header);
 
 	in  = (unsigned char __LZO_MMODEL *)((pointer_addr_t)nffile->block_header     + sizeof(data_block_header_t));	
@@ -934,7 +932,8 @@ lzo_uint out_len;
 		return ret;
 	} 
 
-	out_block_header = (data_block_header_t *)lzo_buff;
+	/* modified by libnf patch */
+	out_block_header = (data_block_header_t *)nffile->lzo_buff;
 	*out_block_header = *(block_header);
 
 	in  = (unsigned char __LZO_MMODEL *)((pointer_addr_t)block_header     + sizeof(data_block_header_t));	
