@@ -1,4 +1,23 @@
+/* 
 
+ Copyright (c) 2013-2015, Tomas Podermanski
+    
+ This file is part of libnf.net project.
+
+ Libnf is free software: you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation, either version 3 of the License, or
+ (at your option) any later version.
+
+ Libnf is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public License
+ along with libnf.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 #include "config.h"
 
@@ -666,6 +685,20 @@ static int inline lnf_field_fset_FW_XEVENT(master_record_t *m, void *p, bit_arra
 	/* dummy record for check_items_map.pl m->xlate_flags */
 }
 
+/* ----------------------- */
+static int inline lnf_field_fget_FW_EVENT(master_record_t *m, void *p, bit_array_t *e) { 
+	*((uint8_t *)p) = m->event;
+	return __bit_array_get(e, EX_NSEL_COMMON) ? LNF_OK : LNF_ERR_NOTSET;
+	/* dummy record for check_items_map.pl m->xlate_flags */
+}
+
+static int inline lnf_field_fset_FW_EVENT(master_record_t *m, void *p, bit_array_t *e) { 
+	m->event = *((uint8_t *)p);
+	__bit_array_set(e, EX_NSEL_COMMON, 1);
+	return LNF_OK;
+	/* dummy record for check_items_map.pl m->xlate_flags */
+}
+
 /* ----------------------- */
 static int inline lnf_field_fget_XLATE_SRC_IP(master_record_t *m, void *p, bit_array_t *e) { 
 	ip_addr_t *d = (ip_addr_t *)&m->xlate_src_ip;
@@ -1365,6 +1398,13 @@ lnf_field_def_t lnf_fields_def[] = {
 		lnf_field_fget_FW_XEVENT,
 		lnf_field_fset_FW_XEVENT},
 
+	[LNF_FLD_FW_EVENT] = {
+		LNF_UINT8,		LNF_AGGR_KEY,	LNF_SORT_ASC,	
+		{LNF_FLD_ZERO_, LNF_FLD_ZERO_},
+		"event",		"NSEL Extended event code",
+		lnf_field_fget_FW_EVENT,
+		lnf_field_fset_FW_EVENT},
+
 	[LNF_FLD_XLATE_SRC_IP] = {
 		LNF_ADDR,		LNF_AGGR_KEY,	LNF_SORT_ASC,	
 		{LNF_FLD_ZERO_, LNF_FLD_ZERO_},
